@@ -1,13 +1,23 @@
 # Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved
 import os
+import sys
 from typing import List, Optional
 
-import importlib_resources
 from omegaconf import OmegaConf
 
 from hydra.core.object_type import ObjectType
 from hydra.plugins.config_source import ConfigLoadError, ConfigResult, ConfigSource
 
+if sys.version_info.major >= 4 or (
+    sys.version_info.major >= 3 and sys.version_info.minor >= 9
+):
+    from importlib import resources
+else:
+    import importlib_resources as resources  # type:ignore
+
+    # Relevant issue: https://github.com/python/mypy/issues/1153
+    # Use importlib backport for Python older than 3.9
+
 
 class ImportlibResourcesConfigSource(ConfigSource):
     def __init__(self, provider: str, path: str) -> None:
@@ -26,11 +36,11 @@ class ImportlibResourcesConfigSource(ConfigSource):
         package_override: Optional[str] = None,
     ) -> ConfigResult:
         normalized_config_path = self._normalize_file_name(config_path)
-        res = importlib_resources.files(self.path).joinpath(normalized_config_path)
+        res = resources.files(self.path).joinpath(normalized_config_path)  # type:ignore
         if not res.exists():
             raise ConfigLoadError(f"Config not found : {normalized_config_path}")
 
-        with open(res, encoding="utf-8") as f:
+        with res.open(encoding="utf-8") as f:
             header_text = f.read(512)
             header = ConfigSource._get_header_dict(header_text)
             self._update_package_in_header(
@@ -50,7 +60,7 @@ class ImportlibResourcesConfigSource(ConfigSource):
 
     def available(self) -> bool:
         try:
-            ret = importlib_resources.is_resource(self.path, "__init__.py")
+            ret = resources.is_resource(self.path, "__init__.py")  # type:ignore
             assert isinstance(ret, bool)
             return ret
         except ValueError:
@@ -60,7 +70,7 @@ class ImportlibResourcesConfigSource(ConfigSource):
 
     def is_group(self, config_path: str) -> bool:
         try:
-            files = importlib_resources.files(self.path)
+            files = resources.files(self.path)  # type:ignore
         except Exception:
             return False
 
@@ -72,7 +82,7 @@ class ImportlibResourcesConfigSource(ConfigSource):
     def is_config(self, config_path: str) -> bool:
         config_path = self._normalize_file_name(config_path)
         try:
-            files = importlib_resources.files(self.path)
+            files = resources.files(self.path)  # type:ignore
         except Exception:
             return False
         res = files.joinpath(config_path)
@@ -83,7 +93,7 @@ class ImportlibResourcesConfigSource(ConfigSource):
     def list(self, config_path: str, results_filter: Optional[ObjectType]) -> List[str]:
         files: List[str] = []
         for file in (
-            importlib_resources.files(self.path).joinpath(config_path).iterdir()
+            resources.files(self.path).joinpath(config_path).iterdir()  # type:ignore
         ):
             fname = file.name
             fpath = os.path.join(config_path, fname)
