@@ -15,7 +15,7 @@ from hydra import MissingConfigException
 from hydra.test_utils.test_utils import (
     TSweepRunner,
     TTaskRunner,
-    assert_text_same,
+    assert_regex_match,
     chdir_hydra_root,
     get_run_output,
     integration_test,
@@ -1028,9 +1028,9 @@ def test_app_with_error_exception_sanitized(tmpdir: Any, monkeypatch: Any) -> No
         "hydra.sweep.dir=" + str(tmpdir),
     ]
     expected = """Traceback (most recent call last):
-  File "my_app.py", line 13, in my_app
+  File ".*my_app.py", line 13, in my_app
     foo(cfg)
-  File "my_app.py", line 8, in foo
+  File ".*my_app.py", line 8, in foo
     cfg.foo = "bar"  # does not exist in the config
 omegaconf.errors.ConfigAttributeError: Key 'foo' is not in struct
 \tfull_key: foo
@@ -1040,7 +1040,12 @@ omegaconf.errors.ConfigAttributeError: Key 'foo' is not in struct
 Set the environment variable HYDRA_FULL_ERROR=1 for a complete stack trace."""
 
     ret = run_with_error(cmd)
-    assert normalize_newlines(expected) == normalize_newlines(ret)
+    assert_regex_match(
+        from_line=expected,
+        to_line=ret,
+        from_name="Expected output",
+        to_name="Actual output",
+    )
 
 
 def test_hydra_to_job_config_interpolation(tmpdir: Any) -> Any:
@@ -1128,7 +1133,7 @@ class TestTaskRunnerLogging:
             dedent(
                 """\
                 Traceback (most recent call last):
-                  File "my_app.py", line 9, in my_app
+                  File ".*my_app.py", line 9, in my_app
                     1 / 0
                 ZeroDivisionError: division by zero
 
@@ -1138,11 +1143,14 @@ class TestTaskRunnerLogging:
         ),
     ],
 )
-def test_hydra_exception(monkeypatch: Any, tmpdir: Any, expected: str) -> None:
+def test_hydra_exception(
+    monkeypatch: Any,
+    tmpdir: Any,
+    expected: str,
+) -> None:
     monkeypatch.chdir("tests/test_apps/app_exception")
     ret = run_with_error(["my_app.py", f"hydra.run.dir={tmpdir}"])
-
-    assert_text_same(
+    assert_regex_match(
         from_line=expected,
         to_line=ret,
         from_name="Expected output",
